# -*- coding: utf-8 -*-
import os
from pathlib import Path

import pytest

from arkindex.mock import MockApiClient
from arkindex_export import open_database
from arkindex_worker.worker.base import BaseWorker

DATA_PATH: Path = Path(__file__).parent / "data"


@pytest.fixture(autouse=True)
def setup_environment(responses, monkeypatch):
    """Setup needed environment variables"""

    # Allow accessing remote API schemas
    # defaulting to the prod environment
    schema_url = os.environ.get(
        "ARKINDEX_API_SCHEMA_URL",
        "https://arkindex.teklia.com/api/v1/openapi/?format=openapi-json",
    )
    responses.add_passthru(schema_url)

    # Set schema url in environment
    os.environ["ARKINDEX_API_SCHEMA_URL"] = schema_url
    # Setup a fake worker run ID
    os.environ["ARKINDEX_WORKER_RUN_ID"] = "1234-generic-training-dataset"

    # Setup a mock api client instead of using a real one
    def mock_setup_api_client(self):
        self.api_client = MockApiClient()

    monkeypatch.setattr(BaseWorker, "setup_api_client", mock_setup_api_client)


@pytest.fixture(scope="session", autouse=True)
def arkindex_db() -> None:
    open_database(DATA_PATH / "arkindex_export.sqlite")


@pytest.fixture
def page_1_image() -> bytes:
    with (DATA_PATH / "sample_image_1.jpg").open("rb") as image:
        return image.read()


@pytest.fixture
def page_2_image() -> bytes:
    with (DATA_PATH / "sample_image_2.jpg").open("rb") as image:
        return image.read()


@pytest.fixture
def downloaded_images(responses, page_1_image, page_2_image) -> None:
    # Mock image download call
    # Page 1
    responses.add(
        responses.GET,
        "https://europe-gamma.iiif.teklia.com/iiif/2/public%2Fiam%2Fg06-018m.png/0,0,2479,3542/full/0/default.jpg",
        body=page_1_image,
    )
    # Page 2
    responses.add(
        responses.GET,
        "https://europe-gamma.iiif.teklia.com/iiif/2/public%2Fiam%2Fc02-026.png/0,0,2479,3542/full/0/default.jpg",
        body=page_2_image,
    )
